##  Table of Contents
  * [Getting Started](https://help.sap.com/docs/leanix/ea/getting-started?locale=en-US&state=PRODUCTION&version=CLOUD)
    * [SAP LeanIX for Enterprise Architects](https://help.sap.com/docs/leanix/ea/for-enterprise-architects?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Set Up User Access](https://help.sap.com/docs/leanix/ea/set-up-user-access?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Getting Data into Your Workspace](https://help.sap.com/docs/leanix/ea/get-data-into-workspace?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Use Cases](https://help.sap.com/docs/leanix/ea/use-cases?locale=en-US&state=PRODUCTION&version=CLOUD)
    * [SAP LeanIX for Application and Business Owners](https://help.sap.com/docs/leanix/ea/for-application-and-business-owners?locale=en-US&state=PRODUCTION&version=CLOUD)
    * [Navigating SAP LeanIX](https://help.sap.com/docs/leanix/ea/navigation?locale=en-US&state=PRODUCTION&version=CLOUD)
    * [SAP LeanIX Resources](https://help.sap.com/docs/leanix/ea/resources?locale=en-US&state=PRODUCTION&version=CLOUD)
    * [FAQs](https://help.sap.com/docs/leanix/ea/faqs?locale=en-US&state=PRODUCTION&version=CLOUD)
    * [Contact Support](https://help.sap.com/docs/leanix/ea/contact-support?locale=en-US&state=PRODUCTION&version=CLOUD)
    * [Onboarding Journey](https://help.sap.com/docs/leanix/ea/onboarding-journey?locale=en-US&state=PRODUCTION&version=CLOUD)
    * [Migration of SAP LeanIX Academy Courses to SAP Learning](https://help.sap.com/docs/leanix/ea/migration-of-sap-leanix-academy-courses-to-sap-learning?locale=en-US&state=PRODUCTION&version=CLOUD)
  * [Meta Model](https://help.sap.com/docs/leanix/ea/meta-model?locale=en-US&state=PRODUCTION&version=CLOUD)
    * [General Modeling Guidelines](https://help.sap.com/docs/leanix/ea/general-modeling-guidelines?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Using Tags and Custom Fields](https://help.sap.com/docs/leanix/ea/tags-and-custom-fields?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Using Relations](https://help.sap.com/docs/leanix/ea/relations?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Modeling and Reports](https://help.sap.com/docs/leanix/ea/modeling-and-reports?locale=en-US&state=PRODUCTION&version=CLOUD)
    * [Fact Sheet Modeling Guidelines](https://help.sap.com/docs/leanix/ea/fact-sheet-modeling-guidelines?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Application Modeling Guidelines](https://help.sap.com/docs/leanix/ea/application-modeling-guidelines?locale=en-US&state=PRODUCTION&version=CLOUD)
        * [Microservice Modeling Guidelines](https://help.sap.com/docs/leanix/ea/microservice-modeling-guidelines?locale=en-US&state=PRODUCTION&version=CLOUD)
        * [AI Agent Modeling Guidelines](https://help.sap.com/docs/leanix/ea/ai-agent-modeling-guidelines?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Business Capability Modeling Guidelines](https://help.sap.com/docs/leanix/ea/business-capability-modeling-guidelines?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Business Context Modeling Guidelines](https://help.sap.com/docs/leanix/ea/business-context-modeling-guidelines?locale=en-US&state=PRODUCTION&version=CLOUD)
        * [ESG Capability Modeling Guidelines](https://help.sap.com/docs/leanix/ea/esg-capability-modeling-guidelines?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Data Object Modeling Guidelines](https://help.sap.com/docs/leanix/ea/data-object-modeling-guidelines?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Initiative Modeling Guidelines](https://help.sap.com/docs/leanix/ea/initiative-modeling-guidelines?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Interface Modeling Guidelines](https://help.sap.com/docs/leanix/ea/interface-modeling-guidelines?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [IT Component Modeling Guidelines](https://help.sap.com/docs/leanix/ea/it-component-modeling-guidelines?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Objective Modeling Guidelines](https://help.sap.com/docs/leanix/ea/objective-modeling-guidelines?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Organization Modeling Guidelines](https://help.sap.com/docs/leanix/ea/organization-modeling-guidelines?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Platform Modeling Guidelines](https://help.sap.com/docs/leanix/ea/platform-modeling-guidelines?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Provider Modeling Guidelines](https://help.sap.com/docs/leanix/ea/provider-modeling-guidelines?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Tech Category Modeling Guidelines](https://help.sap.com/docs/leanix/ea/tech-category-modeling-guidelines?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [System Modeling Guidelines](https://help.sap.com/docs/leanix/ea/system-modeling-guidelines?locale=en-US&state=PRODUCTION&version=CLOUD)
    * [Modeling Best Practices](https://help.sap.com/docs/leanix/ea/modeling-best-practices?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [SAP Modeling Best Practices](https://help.sap.com/docs/leanix/ea/sap-modeling-best-practices?locale=en-US&state=PRODUCTION&version=CLOUD)
        * [Modeling SAP Cloud Solutions](https://help.sap.com/docs/leanix/ea/modeling-sap-cloud-solutions?locale=en-US&state=PRODUCTION&version=CLOUD)
        * [Modeling SAP S/4HANA](https://help.sap.com/docs/leanix/ea/modeling-sap-s4hana?locale=en-US&state=PRODUCTION&version=CLOUD)
        * [Modeling SAP BTP](https://help.sap.com/docs/leanix/ea/modeling-sap-btp?locale=en-US&state=PRODUCTION&version=CLOUD)
        * [Modeling SAP Interfaces and External Partners](https://help.sap.com/docs/leanix/ea/modeling-sap-interfaces-and-external-partners?locale=en-US&state=PRODUCTION&version=CLOUD)
        * [Modeling SAP ERP 6.0](https://help.sap.com/docs/leanix/ea/modeling-sap-erp-60?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Microsoft Applications Modeling Best Practices](https://help.sap.com/docs/leanix/ea/microsoft-applications-modeling-best-practices?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Google Cloud Platform Modeling Best Practices](https://help.sap.com/docs/leanix/ea/google-cloud-platform-modeling-best-practices?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Salesforce Applications Modeling Best Practices](https://help.sap.com/docs/leanix/ea/salesforce-applications-modeling-best-practices?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [AWS Applications Modeling Best Practices](https://help.sap.com/docs/leanix/ea/aws-applications-modeling-best-practices?locale=en-US&state=PRODUCTION&version=CLOUD)
    * [Meta Model Extensions](https://help.sap.com/docs/leanix/ea/meta-model-extensions?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [AI Governance Extension to the Meta Model](https://help.sap.com/docs/leanix/ea/meta-model-ai-governance-extension?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Digital Operational Resilience Act (DORA) Extension to the Meta Model](https://help.sap.com/docs/leanix/ea/meta-model-dora-extension?locale=en-US&state=PRODUCTION&version=CLOUD)
        * [Digital Operational Resilience Act (DORA) Attributes](https://help.sap.com/docs/leanix/ea/digital-operational-resilience-act-dora-attributes?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Application Total Cost of Ownership (TCO) Extension](https://help.sap.com/docs/leanix/ea/application-total-cost-of-ownership-extension?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [AI Agent Extension to the Meta Model](https://help.sap.com/docs/leanix/ea/ai-agent-extension-to-meta-model?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [IT Component Naming Rule Extension](https://help.sap.com/docs/leanix/ea/it-component-naming-rule-extension?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [SAP Suggestions in Your Landscape Extension to the Meta Model](https://help.sap.com/docs/leanix/ea/sap-suggestions?locale=en-US&state=PRODUCTION&version=CLOUD)
    * [Meta Model v3](https://help.sap.com/docs/leanix/ea/meta-model-v3?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Delta to Meta Model v3](https://help.sap.com/docs/leanix/ea/delta-to-meta-model-v3?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Configure Workspace for Meta Model v4](https://help.sap.com/docs/leanix/ea/configure-workspace-meta-model-v4?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Modeling Guidelines (Meta Model v3)](https://help.sap.com/docs/leanix/ea/modeling-guidelines-v3?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Modeling: Application vs. IT component](https://help.sap.com/docs/leanix/ea/application-vs-it-component-v3?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Modeling: Objectives and Transformation Items (Projects) (Meta Model v3)](https://help.sap.com/docs/leanix/ea/objectives-and-transformations-items-v3?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Modeling: Business Capabilities (Meta Model v3)](https://help.sap.com/docs/leanix/ea/business-capabilities-modeling-v3?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Modeling: Data Object (Meta Model v3)](https://help.sap.com/docs/leanix/ea/data-object-modeling-v3?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Modeling: Interfaces (Meta Model v3)](https://help.sap.com/docs/leanix/ea/interfaces-modeling-v3?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Modeling: IT Components / Hosting (Meta Model v3)](https://help.sap.com/docs/leanix/ea/it-components-hosting-modeling-v3?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Modeling: Middleware and APIs (Meta Model v3)](https://help.sap.com/docs/leanix/ea/middleware-and-apis-modeling-v3?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Modeling: Process (Meta Model v3)](https://help.sap.com/docs/leanix/ea/process-modeling-v3?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Modeling: Project Fact Sheet (Meta Model v3)](https://help.sap.com/docs/leanix/ea/project-modeling-v3?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Modeling: Tech Category (Meta Model v3)](https://help.sap.com/docs/leanix/ea/tech-category-modeling-v3?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Modeling: User Group (Meta Model V3 )](https://help.sap.com/docs/leanix/ea/user-group-modeling-v3?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Optional Features: Tech Platform Fact Sheet (Meta Model v3)](https://help.sap.com/docs/leanix/ea/tech-platform-fact-sheet-v3?locale=en-US&state=PRODUCTION&version=CLOUD)
  * [Use Cases and Methodologies](https://help.sap.com/docs/leanix/ea/use-cases-methodologies?locale=en-US&state=PRODUCTION&version=CLOUD)
    * [Application Portfolio Assessment](https://help.sap.com/docs/leanix/ea/application-portfolio-assessment?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Step 1: Add Data](https://help.sap.com/docs/leanix/ea/application-portfolio-assessment-define-scope?locale=en-US&state=PRODUCTION&version=CLOUD)
        * [Add Applications](https://help.sap.com/docs/leanix/ea/add-applications?locale=en-US&state=PRODUCTION&version=CLOUD)
        * [Add Business Capabilities](https://help.sap.com/docs/leanix/ea/add-business-capabilities?locale=en-US&state=PRODUCTION&version=CLOUD)
        * [Add Organizations](https://help.sap.com/docs/leanix/ea/add-organizations?locale=en-US&state=PRODUCTION&version=CLOUD)
        * [Add Relations](https://help.sap.com/docs/leanix/ea/add-relations?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Step 2: Collect and Maintain Data](https://help.sap.com/docs/leanix/ea/application-portfolio-assessment-enrich-data?locale=en-US&state=PRODUCTION&version=CLOUD)
        * [Identify and Assign Fact Sheet Owners](https://help.sap.com/docs/leanix/ea/assign-fact-sheet-owners?locale=en-US&state=PRODUCTION&version=CLOUD)
        * [Configure Data Quality Controls](https://help.sap.com/docs/leanix/ea/configure-data-quality-controls?locale=en-US&state=PRODUCTION&version=CLOUD)
        * [Onboard Fact Sheet Owners and Collect Data](https://help.sap.com/docs/leanix/ea/collect-data-from-fact-sheet-owners?locale=en-US&state=PRODUCTION&version=CLOUD)
        * [Key Attributes for Application Portfolio Assessment](https://help.sap.com/docs/leanix/ea/key-attributes-for-application-portfolio-assessment?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Step 3. Assess Your Application Portfolio](https://help.sap.com/docs/leanix/ea/application-portfolio-assessment-assess-portfolio?locale=en-US&state=PRODUCTION&version=CLOUD)
    * [Application Rationalization](https://help.sap.com/docs/leanix/ea/application-rationalization?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Step 1: Understand Your Strategy](https://help.sap.com/docs/leanix/ea/application-rationalization-understand-strategy?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Step 2: Scope Applications](https://help.sap.com/docs/leanix/ea/application-rationalization-scope-applications?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Step 3: Enrich Data](https://help.sap.com/docs/leanix/ea/application-rationalization-enrich-data?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Step 4: Evaluate Data](https://help.sap.com/docs/leanix/ea/application-rationalization-evaluate-data?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Step 5: Create a Rationalization Roadmap](https://help.sap.com/docs/leanix/ea/application-rationalization-create-roadmap?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Step 6: Start the Rationalization Initiative](https://help.sap.com/docs/leanix/ea/application-rationalization-start-initiative?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Step 7: Track and Report](https://help.sap.com/docs/leanix/ea/application-rationalization-track-report?locale=en-US&state=PRODUCTION&version=CLOUD)
    * [Application Modernization](https://help.sap.com/docs/leanix/ea/application-modernization?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Step 1: Understand Your Strategy](https://help.sap.com/docs/leanix/ea/application-modernization-understand-strategy?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Step 2: Scope Applications](https://help.sap.com/docs/leanix/ea/application-modernization-scope-applications?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Step 3: Collect Data](https://help.sap.com/docs/leanix/ea/application-modernization-collect-data?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Step 4: Evaluate Data](https://help.sap.com/docs/leanix/ea/application-modernization-evaluate-data?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Step 5: Plan Transformations and Create a Roadmap](https://help.sap.com/docs/leanix/ea/application-modernization-transformations-and-roadmap?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Step 6: Start Modernization](https://help.sap.com/docs/leanix/ea/application-modernization-start-initiative?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Step 7: Track and Report](https://help.sap.com/docs/leanix/ea/application-modernization-track-report?locale=en-US&state=PRODUCTION&version=CLOUD)
    * [ERP Transformation](https://help.sap.com/docs/leanix/ea/erp-transformation?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Phase 0. Foundation: Transformation Strategy and Setup](https://help.sap.com/docs/leanix/ea/erp-transformation-foundation?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Phase 1. Discover: Achieve Architecture Transparency](https://help.sap.com/docs/leanix/ea/erp-transformation-discover?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Phase 2. Prepare the Transformation](https://help.sap.com/docs/leanix/ea/erp-transformation-prepare?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Phase 3. Explore: Define the To-Be Architecture](https://help.sap.com/docs/leanix/ea/erp-transformation-explore?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Phase 4. Realize, Deploy, and Run: Transformations and Monitoring](https://help.sap.com/docs/leanix/ea/erp-transformation-realize-deploy-run?locale=en-US&state=PRODUCTION&version=CLOUD)
    * [SAP ERP Transformation with Integrated Toolchain](https://help.sap.com/docs/leanix/ea/erp-transformation-with-rise-with-sap-integrated-toolchain?locale=en-US&state=PRODUCTION&version=CLOUD)
    * [Obsolescence Risk Management](https://help.sap.com/docs/leanix/ea/obsolescence-risk-management?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Step 1: Bring Software Assets Information to SAP LeanIX](https://help.sap.com/docs/leanix/ea/obsolescence-risk-management-import-software-assets?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Step 2: Enrich Data](https://help.sap.com/docs/leanix/ea/obsolescence-risk-management-enrich-data?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Step 3: Discover and Prioritize Technology Obsolescence Risks](https://help.sap.com/docs/leanix/ea/obsolescence-risk-management-discover-prioritize-risks?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Step 4: Plan and Manage Risk Mitigation Initiatives](https://help.sap.com/docs/leanix/ea/obsolescence-risk-management-plan-manage-mitigation?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Step 5: Monitor, Measure, and Report Risk Mitigation Efforts](https://help.sap.com/docs/leanix/ea/obsolescence-risk-management-monitor-mitigation?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Advanced Practices](https://help.sap.com/docs/leanix/ea/obsolescence-risk-management-advanced?locale=en-US&state=PRODUCTION&version=CLOUD)
    * [AI Governance](https://help.sap.com/docs/leanix/ea/ai-governance-and-adoption?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Step 1: Collect Data](https://help.sap.com/docs/leanix/ea/ai-governance-and-adoption-collect-information?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Step 2: Assess AI Potential and Usage](https://help.sap.com/docs/leanix/ea/ai-governance-and-adoption-assess-potential?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Step 3: Evaluate AI-Related Risks](https://help.sap.com/docs/leanix/ea/ai-governance-and-adoption-evaluate-risks?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Step 4: Standardize AI Usage](https://help.sap.com/docs/leanix/ea/ai-governance-and-adoption-standardize-usage?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Step 5: Create AI-Related Transformations](https://help.sap.com/docs/leanix/ea/ai-governance-and-adoption-plan-transformations?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Step 6: Track and Report](https://help.sap.com/docs/leanix/ea/step-6-track-and-report?locale=en-US&state=PRODUCTION&version=CLOUD)
    * [Portfolio Assessment Methodologies](https://help.sap.com/docs/leanix/ea/portfolio-assessment-methodologies?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Gartner® TIME Framework](https://help.sap.com/docs/leanix/ea/time?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [6R Framework](https://help.sap.com/docs/leanix/ea/6r?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Pace Layering Framework](https://help.sap.com/docs/leanix/ea/pace-layering?locale=en-US&state=PRODUCTION&version=CLOUD)
        * [Modeling Pace Layers](https://help.sap.com/docs/leanix/ea/modeling-pace-layers?locale=en-US&state=PRODUCTION&version=CLOUD)
        * [Application of Pace Layering in Assessments](https://help.sap.com/docs/leanix/ea/application-of-pace-layering-in-assessments?locale=en-US&state=PRODUCTION&version=CLOUD)
  * [User Guide](https://help.sap.com/docs/leanix/ea/user-guide?locale=en-US&state=PRODUCTION&version=CLOUD)
    * [Dashboards](https://help.sap.com/docs/leanix/ea/dashboards?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Dashboard Modeling](https://help.sap.com/docs/leanix/ea/dashboard-modeling?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Application Portfolio Management Dashboard](https://help.sap.com/docs/leanix/ea/application-portfolio-management-dashboard?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Fact Sheet Owner Onboarding Dashboard](https://help.sap.com/docs/leanix/ea/fact-sheet-owner-onboarding-dashboard?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Application Portfolio Management Onboarding Dashboard for Enterprise Architects](https://help.sap.com/docs/leanix/ea/application-portfolio-management-onboarding-dashboard-for-enterprise-architects?locale=en-US&state=PRODUCTION&version=CLOUD)
        * [Onboarding Guide for SAP LeanIX Application Portfolio Management](https://help.sap.com/docs/leanix/ea/onboarding-guide-application-portfolio-management?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Architecture Executive Dashboard](https://help.sap.com/docs/leanix/ea/architecture-executive-dashboard?locale=en-US&state=PRODUCTION&version=CLOUD)
        * [Configuring the Architecture Executive Dashboard](https://help.sap.com/docs/leanix/ea/configure-architecture-executive-dashboard?locale=en-US&state=PRODUCTION&version=CLOUD)
        * [Navigating the Architecture Executive Dashboard](https://help.sap.com/docs/leanix/ea/navigate-architecture-executive-dashboard?locale=en-US&state=PRODUCTION&version=CLOUD)
        * [Using and Analyzing Executive KPIs](https://help.sap.com/docs/leanix/ea/kpi-insights?locale=en-US&state=PRODUCTION&version=CLOUD)
        * [Executive KPIs](https://help.sap.com/docs/leanix/ea/executive-kpis?locale=en-US&state=PRODUCTION&version=CLOUD)
    * [Inventory](https://help.sap.com/docs/leanix/ea/inventory?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Fact Sheets](https://help.sap.com/docs/leanix/ea/fact-sheets?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Creating Fact Sheets](https://help.sap.com/docs/leanix/ea/creating-fact-sheets?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Adding and Editing Data in Fact Sheets](https://help.sap.com/docs/leanix/ea/adding-and-editing-data-in-fact-sheets?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Bulk Updating Data in Inventory Table View](https://help.sap.com/docs/leanix/ea/bulk-updating-data-in-inventory-table-view?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Collaborating and Managing Data in Fact Sheets](https://help.sap.com/docs/leanix/ea/collaborating-and-managing-data-in-fact-sheets?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Importing Fact Sheet Data Through Excel File](https://help.sap.com/docs/leanix/ea/importing-fact-sheet-data-through-excel-file?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Exporting Fact Sheet Data as Excel File](https://help.sap.com/docs/leanix/ea/exporting-fact-sheet-data-as-excel-file?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Increasing Your Data Quality](https://help.sap.com/docs/leanix/ea/increasing-your-data-quality?locale=en-US&state=PRODUCTION&version=CLOUD)
        * [Fact Sheet Completeness](https://help.sap.com/docs/leanix/ea/fact-sheet-completeness?locale=en-US&state=PRODUCTION&version=CLOUD)
        * [Fact Sheet Subscription](https://help.sap.com/docs/leanix/ea/fact-sheet-subscription?locale=en-US&state=PRODUCTION&version=CLOUD)
        * [Quality Seal](https://help.sap.com/docs/leanix/ea/quality-seal?locale=en-US&state=PRODUCTION&version=CLOUD)
        * [Mandatory Attributes](https://help.sap.com/docs/leanix/ea/mandatory-attributes?locale=en-US&state=PRODUCTION&version=CLOUD)
        * [Data Quality Insights](https://help.sap.com/docs/leanix/ea/data-quality-insights?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Searching and Filtering in the Inventory](https://help.sap.com/docs/leanix/ea/searching-and-filtering-in-inventory?locale=en-US&state=PRODUCTION&version=CLOUD)
        * [Advanced Filter Options](https://help.sap.com/docs/leanix/ea/advanced-filter-options?locale=en-US&state=PRODUCTION&version=CLOUD)
        * [Strict Filtering](https://help.sap.com/docs/leanix/ea/strict-filtering?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Tags](https://help.sap.com/docs/leanix/ea/tags?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Archiving, Deleting and Recovering Fact Sheets](https://help.sap.com/docs/leanix/ea/archiving-deleting-and-recovering-fact-sheets?locale=en-US&state=PRODUCTION&version=CLOUD)
    * [Reports](https://help.sap.com/docs/leanix/ea/reports?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Using Reports](https://help.sap.com/docs/leanix/ea/using-reports?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Report Views](https://help.sap.com/docs/leanix/ea/report-views?locale=en-US&state=PRODUCTION&version=CLOUD)
        * [Views Aggregation](https://help.sap.com/docs/leanix/ea/views-aggregation?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Landscape Report](https://help.sap.com/docs/leanix/ea/landscape-report?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Matrix Report](https://help.sap.com/docs/leanix/ea/matrix-report?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Portfolio Report](https://help.sap.com/docs/leanix/ea/portfolio-report?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Roadmap Report](https://help.sap.com/docs/leanix/ea/roadmap-report?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Radar Report](https://help.sap.com/docs/leanix/ea/radar-report?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Circle Map Report](https://help.sap.com/docs/leanix/ea/circle-map-report?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Other Reports](https://help.sap.com/docs/leanix/ea/other-reports?locale=en-US&state=PRODUCTION&version=CLOUD)
